@@ -85,15 +85,6 @@ kana_text_word_list
 
 - 「かな|言葉^11」の書式で指定された文字列をリスト形式で設定する.
 
-html_kana_text_on_genindex
-
-- 索引ページでのかな表示を有効にする. 省略時は非表示. 推奨はTrue.
-- 対応した「genidex.html」が必要. コマンド「sphinx-kana-genindex」で作成される.
-
-html_change_triple
-
-- tripleでの「3rd, 1st」の表示を「1st, 3rd」に変更する. 省略時はFalse.
-
 kana_text_indexer_mode
 
 - 'small': ex.「モジュール」は「ま」の項目.
@@ -101,34 +92,23 @@ kana_text_indexer_mode
 - その他:  ex.「モジュール」は「モ」のまま.
 - 省略時は`small`.
 
+kana_text_on_genindex
+
+- 索引ページでのかな表示を有効にする. 省略時は非表示. 推奨はTrue.
+- 対応した「genidex.html」が必要. コマンド「sphinx-kana-genindex」で作成される.
+
+kana_text_change_triple
+
+- tripleでの「3rd, 1st」の表示を「1st, 3rd」に変更する. 省略時はFalse.
+
 genindex.htmlの作り方
 ---------------------
 コマンド「sphinx-kana-genindex」の実行で、以下の内容のファイルがカレントディレクトリに作成される.
 
 1. sphinx/themes/basic/genindex.html をプロジェクトの「_templates」にコピーする.
-2. 「{{ firstname|e }}」を次のように変更し、続けて同ファイルに「macro」を記述する.
+2. indexentriesマクロにある二つの「{{ firstname|e }}」から「|e」を取り除く。
 
-.. code-block:: jinja
-
-    {{ kana_entry(firstname) }}
-
-.. code-block:: jinja
-
-    {% macro kana_entry(kname) %}
-    {%- if kname is string -%}
-      {{ kname|e }}
-    {%- else %}
-      {%- for isruby, val in kname -%}
-      {%- if isruby -%}
-        <ruby><rb>{{ val[0]|e }}</rb><rp>（</rp>
-        <rt>{{ val[1]|e }}</rt><rp>）<rp>
-        </ruby>
-      {%- else %}
-        {{ val|e }}
-      {%- endif %}
-      {%- endfor %}
-    {%- endif %}
-    {% endmacro %}
+    - 「|e」の代わりに「nodes.unescape」で対処。
 
 開発者向け
 ==========
@@ -155,12 +135,12 @@ ExIndexEntryクラス
 
 visit_kana/depart_kanaメソッド
 
-- add_node()により、KanaTextクラスに紐付けてKanaHTMLBuilderクラスに登録される.
+- add_node()により、KanaTextクラスに紐付けてExHTMLBuilderクラスに登録される.
 - glossaryで記載したテキストは、 **visit_term()** メソッドでKanaTextクラスにする.
 
     - 本来の調整場所はGlossaryクラスだが、コード量の少ないvisit_termメソッドを選択.
 
-KanaHTML5Translatorクラス/visit_termメソッド
+ExHTML5Translatorクラス/visit_termメソッド
 
 - 目的のTextノードをKanaTextノードに変更する.
 
@@ -177,12 +157,12 @@ ExIndexUnitクラス
 
 - 索引ページで表示される各項目に対応したオブジェクトのクラス.
 
-ExSubTermクラス
+ExSubtermクラス
 
 - ExIndexUnitクラス内のsubtermオブジェクトのクラス.
 - KanaTextを最大で二つ持つ.
 
-KanaHTMLBuilderクラス/create_genindexメソッド
+ExHTMLBuilderクラス/create_genindexメソッド
 
 - 索引ページの表示、ソート処理前の「^オプション」の削除を行う.
 
@@ -206,7 +186,7 @@ latexの関連情報
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.25.0' # 2021-10-24
+__version__ = '0.25.1' # 2021-10-25
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 import re, pathlib
@@ -222,7 +202,7 @@ from sphinx.domains.index import IndexDomain, IndexRole
 from sphinx.errors import NoUri
 from sphinx.environment.adapters.indexentries import IndexEntries
 from sphinx.locale import _, __
-from sphinx.util import logging, split_into
+from sphinx.util import logging, split_into, docutils
 from sphinx.util.nodes import process_index_entry
 from sphinx.writers import html5
 
@@ -344,8 +324,9 @@ class KanaText(nodes.Node):
     """
 
     children = () #これでTextクラスと同じ扱いになる.
+    config = None
 
-    def __init__(self, rawword, config=None):
+    def __init__(self, rawword):
         """
         doctest:
 
@@ -354,13 +335,13 @@ class KanaText(nodes.Node):
             <KanaText: len=2 ruby='specific' option='b1' <#text: 'はなこ|はな子'>>
         """
 
-        if config and _dflt_separator != config.kana_text_separator:
-            separator = config.kana_text_separator
+        if self.config and _dflt_separator != self.config.kana_text_separator:
+            separator = self.config.kana_text_separator
         else:
             separator = _dflt_separator
 
-        if config and _dflt_option_marker != config.kana_text_option_marker:
-            option_marker = config.kana_text_option_marker
+        if self.config and _dflt_option_marker != self.config.kana_text_option_marker:
+            option_marker = self.config.kana_text_option_marker
         else:
             option_marker = _dflt_option_marker
 
@@ -413,7 +394,7 @@ class KanaText(nodes.Node):
 
     def __str__(self):
         """jinja2用"""
-        if self.whatiam == 'term' and self.html_kana_text_on_genindex:
+        if self.whatiam == 'term' and self.kana_text_on_genindex:
             return self.ashtml()
         else:
             return self.ashier()
@@ -604,54 +585,6 @@ class ExIndexEntry(idxr.IndexEntry):
 
         return prop
 
-    def askana(self, concat=(', ', 3)):
-        """
-        doctest:
-            >>> ktext = ExIndexEntry('壱壱')
-            >>> ktext.askana()
-            ''
-            >>> ktext = ExIndexEntry('ああ|壱壱^11')
-            >>> ktext.askana()
-            'ああ'
-            >>> ktext = ExIndexEntry('ああ|壱壱^11; いい|弐弐; うう|参参^11')
-            >>> ktext.askana()
-            'ああ, いい, うう'
-        """
-        kana = concat[0].join(k.askana() for k in self)
-        return kana
-
-    def ashier(self, concat=(', ', 3)):
-        """
-        doctest:
-            >>> ktext = ExIndexEntry('壱壱')
-            >>> ktext.ashier()
-            '壱壱'
-            >>> ktext = ExIndexEntry('ああ|壱壱^11')
-            >>> ktext.ashier()
-            '壱壱'
-            >>> ktext = ExIndexEntry('ああ|壱壱^11; いい|弐弐; うう|参参^11')
-            >>> ktext.ashier()
-            '壱壱, 弐弐, 参参'
-        """
-        word = concat[0].join(k.ashier() for k in self)
-        return word
-
-    def astext(self, concat=('; ', 3)):
-        """
-        doctest:
-            >>> ktext = ExIndexEntry('壱壱')
-            >>> ktext.astext()
-            '壱壱'
-            >>> ktext = ExIndexEntry('ああ|壱壱^11')
-            >>> ktext.astext()
-            'ああ|壱壱'
-            >>> ktext = ExIndexEntry('ああ|壱壱^11; いい|弐弐; うう|参参^11')
-            >>> ktext.astext()
-            'ああ|壱壱; いい|弐弐; うう|参参'
-        """
-        text = concat[0].join(k.astext() for k in self)
-        return text
-
     def asruby(self):
         """
         doctest:
@@ -670,60 +603,6 @@ class ExIndexEntry(idxr.IndexEntry):
 
 #------------------------------------------------------------
 
-def KanaRole(name, rawtext, text, lineno, inliner, options={}, content=[]):
-    """「:kana:`かな|単語`」によるルビ表示
-
-    :param name: ロール名. kana
-    :type name: str
-    :param rawtext: ロール名を含む全体. ex. \:kana\:\`たなかはなこ|田中はな子^\`
-    :type rawtext: str
-    :param text: ロール内データ. ex たなかはなこ|田中はな子^
-    :type text: str
-    :param inliner: Inliner object
-    :type inliner: docutils.parsers.rst.states.Inliner
-    :return: 作成したノード
-    :rtype: [node], [システムメッセージ]
-    """
-    node = KanaText(text)
-    return [node], []
-
-def visit_kana(self, node):
-    """KanaTextクラスで作成されたオブジェクトの表示処理"""
-    self.body.append(node.ashtml())
-
-def depart_kana(self, node):
-    """KanaTextクラスで作成されたオブジェクトの表示処理"""
-    pass
-
-#------------------------------------------------------------
-
-class KanaHTML5Translator(html5.HTML5Translator):
-
-    def visit_term(self, node: Element) -> None:
-        """
-        目的の文字列をKanaTextクラスにするための対応.
-        後は、add_nodeで割り当てたメソッドが行う.
-        """
-
-        try:
-            term = KanaText(node[0].astext())
-        except TypeError as e:
-            pass
-        else:
-            #なくても動作しているのだけど、念の為
-            term.parent = node[0].parent
-            term.document = node[0].document
-            term.source = node[0].source
-            term.line = node[0].line
-            term.children = node[0].children
-            #ここまでが念の為
-
-            node[0] = term
-
-        self.body.append(self.starttag(node,'dt',''))
-
-#------------------------------------------------------------
-
 _first_char_small = {
     'あ': 'あ', 'い': 'あ', 'う': 'あ', 'え': 'あ', 'お': 'あ',
     'ア': 'あ', 'イ': 'あ', 'ウ': 'あ', 'エ': 'あ', 'オ': 'あ', 
@@ -821,7 +700,7 @@ class ExIndexRack(idxr.IndexRack):
         for rawword in builder.config.kana_text_word_list:
             entry = ExIndexEntry(rawword, 'list', 'WORD_LIST', '', 'conf.py', None) #_cnfpy_
             entry.unitclass = ExIndexUnit
-            entry.packclass = ExSubTerm
+            entry.packclass = ExSubterm
             index_units = entry.make_index_units()
             for iu in index_units:
                 self.put_in_kana_catalog(iu[self.UNIT_EMPH], iu.get_children())
@@ -830,7 +709,7 @@ class ExIndexRack(idxr.IndexRack):
         for rawword in get_word_list_from_file(builder.config):
             entry = ExIndexEntry(rawword, 'list', 'WORD_FILE', '', 'valuerc', None) #_rncmd_
             entry.unitclass = ExIndexUnit
-            entry.packclass = ExSubTerm
+            entry.packclass = ExSubterm
             index_units = entry.make_index_units()
             for iu in index_units:
                 self.put_in_kana_catalog(iu[self.UNIT_EMPH], iu.get_children())
@@ -850,7 +729,7 @@ class ExIndexRack(idxr.IndexRack):
         self.textclass = KanaText
         self.entryclass = ExIndexEntry
         self.unitclass = ExIndexUnit
-        self.packclass = ExSubTerm
+        self.packclass = ExSubterm
 
         return super().create_genindex(group_entries, _fixre)
 
@@ -860,7 +739,7 @@ class ExIndexRack(idxr.IndexRack):
         """
         #情報収集
         self.put_in_kana_catalog(unit[self.UNIT_EMPH], unit.get_children()) 
-        unit[self.UNIT_TERM].html_kana_text_on_genindex = self.config.html_kana_text_on_genindex
+        unit[self.UNIT_TERM].kana_text_on_genindex = self.config.kana_text_on_genindex
 
         #残りの処理
         super().append(unit)
@@ -914,7 +793,7 @@ class ExIndexRack(idxr.IndexRack):
         #__init__で貯めた情報を追加する.
         self._kana_catalog.update(self._kana_catalog_pre)
 
-        #カタログ情報を使った更新
+        #カタログ情報を使った更新/kana_text_change_tripleの反映
         for unit in self._rack:
             assert [unit[self.UNIT_TERM]]
 
@@ -925,6 +804,9 @@ class ExIndexRack(idxr.IndexRack):
             for subterm in unit[self.UNIT_SBTM]._terms:
                 self.update_term_with_kana_catalog(subterm)
 
+            #kana_text_change_tripleの設定値を反映
+            unit[self.UNIT_SBTM].change_triple = self.config.kana_text_change_triple
+
         super().update_units()
 
     def get_word(self, term):
@@ -938,11 +820,9 @@ class ExIndexRack(idxr.IndexRack):
         else:
             pass
 
-class ExSubTerm(idxr.SubTerm):
-    """
-    Jinja2に「文字列」と思わせるには「node.repruniocde」の継承が必要.
-    （実体はstrだけど、Sphinxの流儀に従っていた方が無難）
-    """
+class ExSubterm(idxr.Subterm):
+    """subterm in IndexUnit"""
+
     def __init__(self, emphasis, *terms):
         self.change_triple = False
         super().__init__(emphasis, *terms)
@@ -961,8 +841,8 @@ class ExSubTerm(idxr.SubTerm):
         if self._template and len(self) == 1:
             return self._template % self._terms[0].ashier()
 
-        if self.change_triple and len(self) == 2:
-            return self[1].ashier() + self._delimiter + self[0].ashier()
+        if self.change_triple and len(self) == 2 and self._delimiter == ', ':
+            return self._terms[1].ashier() + self._delimiter + self._terms[0].ashier()
 
         hier = ""
         for subterm in self._terms:
@@ -970,32 +850,55 @@ class ExSubTerm(idxr.SubTerm):
         return hier[:-len(self._delimiter)]
 
 class ExIndexUnit(idxr.IndexUnit):
-
-    CLSF, TERM, SBTM, EMPH = 0, 1, 2, 3
-
-    def __init__(self, term, subterm, emphasis, file_name, target, index_key):
-        super().__init__(term, subterm, emphasis, file_name, target, index_key)
-
-    def askanas(self):
-        kanas = [self[self.TERM].askana()]
-
-        for subterm in self[self.SBTM]._terms:
-            kanas.append(subterm.askana())
-
-        return kanas
-
-    def ashiers(self):
-        """Textなら、astexts()になっている."""
-        terms = [self[self.TERM].ashier()]
-
-        for subterm in self[self.SBTM]._terms:
-            terms.append(subterm.ashier())
-
-        return terms
+    pass
 
 #------------------------------------------------------------
 
-class KanaHTMLBuilder(idxr.HTMLBuilder):
+class ExRole(docutils.SphinxRole):
+    """「:kana:`かな|単語`」によるルビ表示"""
+
+    def run(self):
+        node = KanaText(self.text)
+        return [node], []
+
+def visit_kana(self, node):
+    """KanaTextクラスで作成されたオブジェクトの表示処理"""
+    self.body.append(node.ashtml())
+
+def depart_kana(self, node):
+    """KanaTextクラスで作成されたオブジェクトの表示処理"""
+    pass
+
+#------------------------------------------------------------
+
+class ExHTML5Translator(html5.HTML5Translator):
+
+    def visit_term(self, node: Element) -> None:
+        """
+        目的の文字列をKanaTextクラスにするための対応.
+        後は、add_nodeで割り当てたメソッドが行う.
+        """
+
+        try:
+            term = KanaText(node[0].astext())
+        except TypeError as e:
+            pass
+        else:
+            #なくても動作しているのだけど、念の為
+            term.parent = node[0].parent
+            term.document = node[0].document
+            term.source = node[0].source
+            term.line = node[0].line
+            term.children = node[0].children
+            #ここまでが念の為
+
+            node[0] = term
+
+        self.body.append(self.starttag(node,'dt',''))
+
+#------------------------------------------------------------
+
+class ExHTMLBuilder(idxr.HTMLBuilder):
     """索引ページの日本語対応"""
 
     name = 'kana'
@@ -1007,38 +910,8 @@ class KanaHTMLBuilder(idxr.HTMLBuilder):
 
 #------------------------------------------------------------
 
-class _IndexRole(IndexRole):
-    """
-    変更点は次の通り
-    - 変更前）text = nodes.Text(title, title)
-    - 変更後）text = self.create_textnode(title, title)
-    """
-    def create_textnode(sefl, text, rawtext):
-        return Text(text, rawtext)
-
-    def run(self) -> Tuple[List[Node], List[system_message]]:
-        target_id = 'index-%s' % self.env.new_serialno('index')
-        if self.has_explicit_title:
-            # if an explicit target is given, process it as a full entry
-            title = self.title
-            entries = process_index_entry(self.target, target_id)
-        else:
-            # otherwise we just create a single entry
-            if self.target.startswith('!'):
-                title = self.title[1:]
-                entries = [('single', self.target[1:], target_id, 'main', None)]
-            else:
-                title = self.title
-                entries = [('single', self.target, target_id, '', None)]
-
-        index = addnodes.index(entries=entries)
-        target = nodes.target('', '', ids=[target_id])
-        text = self.create_textnode(title, title) #KaKkou
-        self.set_source_info(index)
-        return [index, target, text], []
-
-class KanaIndexRole(_IndexRole):
-    def create_textnode(self, text, rawtext):
+class ExXRefIndex(idxr.XRefIndex):
+    def textclass(self, text, rawtext):
         return KanaText(text)
 
 #------------------------------------------------------------
@@ -1052,19 +925,19 @@ def setup(app) -> Dict[str, Any]:
     :rtype: Dict[name: value]
     """
     #「:index:`かな|単語<かな|単語>`」が使用可能になる
-    app.add_role('index', KanaIndexRole(), True)
+    app.add_role('index', ExXRefIndex(), True)
 
     #「:kana:`かな|単語^11`」が使用可能になる
-    app.add_role('kana', KanaRole)
+    app.add_role('kana', ExRole())
 
     #glossaryディレクティブ、kanaロールの表示用
     app.add_node(KanaText, html=(visit_kana, depart_kana))
     app.add_node(ExIndexEntry, html=(visit_kana, depart_kana))
-    #索引の表示はKanaHTMLBuilderで行う
+    #索引の表示はExHTMLBuilderで行う
 
     #HTML出力
-    app.add_builder(KanaHTMLBuilder)
-    app.set_translator('kana', KanaHTML5Translator)
+    app.add_builder(ExHTMLBuilder)
+    app.set_translator('kana', ExHTML5Translator)
 
     #設定の登録
     app.add_config_value('kana_text_separator', _dflt_separator, 'env') 
@@ -1072,8 +945,8 @@ def setup(app) -> Dict[str, Any]:
     app.add_config_value('kana_text_word_file', '', 'env') 
     app.add_config_value('kana_text_word_list', (), 'env') 
     app.add_config_value('kana_text_indexer_mode', 'small', 'env') 
-    app.add_config_value('html_kana_text_on_genindex', False, 'html') 
-    app.add_config_value('html_change_triple', False, 'html') 
+    app.add_config_value('kana_text_on_genindex', False, 'html') 
+    app.add_config_value('kana_text_change_triple', False, 'html') 
 
     #バージョンの最後は作成日（MMDDYY）
     return {
